--[[----------------------------------------------------------------------------
	Copyright 2009 João Liborio Cardoso
	All rights reserved
	
	BattleRep is free software: you can redistribute it and/or modify it under the terms of the GNU General Public License version 3 as published by the Free Software Foundation.
	BattleRep is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License (<http://www.gnu.org/licenses/>) for more details.
---------------------------------------------------------------------------]]--

local BattleRep = CreateFrame('Frame', 'BattleRep')
LibStub('Efemero-1.1'):Embed(BattleRep)

local L = BattleRep_Locals
local ReputationMatch =  FACTION_STANDING_INCREASED:gsub('%%s', '([%%s%%a]+)'):gsub('%%d%.', '(%%d+)%%.')
local ReputationMessage=  FACTION_STANDING_INCREASED:gsub('%.', ' ') .. L.ThisBattleground


--[[ Startup ]]--

function BattleRep:Startup()
	self:SetScript('OnEvent', function(self, event, ...) self[event](self, ...) end)
	self:RegisterEvent('PLAYER_ENTERING_BATTLEGROUND')
	self:RegisterEvent('UPDATE_BATTLEFIELD_SCORE') --only happens on bg
end


--[[ Events ]]--

function BattleRep:PLAYER_ENTERING_BATTLEGROUND()
	self:RegisterEvent('CHAT_MSG_COMBAT_FACTION_CHANGE')
	self:RegisterEvent('ZONE_CHANGED_NEW_AREA')
	
	BattleRep_Faction = nil
	BattleRep_Total = 0
end

function BattleRep:CHAT_MSG_COMBAT_FACTION_CHANGE(message)
	local faction, increase = strmatch(message, ReputationMatch)
	if increase and L[faction] then
		self:ResetTimer('PrintIncreasedReputation')
		
		BattleRep_Total = (BattleRep_Total or 0) + increase
		BattleRep_Faction = faction
	end
end

function BattleRep:UPDATE_BATTLEFIELD_SCORE()
	if GetBattlefieldWinner() and self:CanPrint() then
		self:SetTimer('PrintIncreasedReputation', 1, nil, 'PrintIncreasedReputation')
	end
end

function BattleRep:ZONE_CHANGED_NEW_AREA()
	if self:CanPrint() then
		self:PrintIncreasedReputation()
	end
	
	if select(2, IsInInstance()) ~= 'pvp' then
		self:UnregisterEvent('CHAT_MSG_COMBAT_FACTION_CHANGE')
		self:UnregisterEvent('ZONE_CHANGED_NEW_AREA')
	end
end


--[[ API ]]--

function BattleRep:CanPrint()
	return BattleRep_Total and BattleRep_Faction
end

function BattleRep:PrintIncreasedReputation()
	local message = ReputationMessage:format(BattleRep_Faction, BattleRep_Total)
	local frame, func
	
	for i = 1, select('#', GetFramesRegisteredForEvent('CHAT_MSG_COMBAT_FACTION_CHANGE')) do
		frame = select(i, GetFramesRegisteredForEvent('CHAT_MSG_COMBAT_FACTION_CHANGE'))
		func = frame:GetScript('OnEvent')
		
		if func then
			func(frame, 'CHAT_MSG_COMBAT_FACTION_CHANGE', message, nil, nil, '')
		end
	end
	
	BattleRep_Total = nil
end


--[[ Start Addon ]]--

BattleRep:Startup()